# -*- coding: utf-8 -*-
#############################################################################
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
__doc__="""ATCTMinimumSample Product for Plone (ATCT)
$Id: smallcontent.py 75 2006-03-03 13:20:22Z taka $"""

__version__='$Rev$'[11:-2]
__product_version__ = "Small 0.0.1"
__author__  = 'Shimizukawa'
__docformat__ = 'plaintext'


from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder
from Products.Archetypes.public import Schema,registerType
from Products.ATContentTypes.content.base import ATCTFolder
from Products.ATContentTypes.content.folder import finalizeATCTSchema
from AccessControl import ClassSecurityInfo

#Fields
from Products.Archetypes.public import StringField,IntegerField,\
                                   LinesField,ReferenceField,BooleanField
#Widgets
from Products.Archetypes.public import StringWidget,TextAreaWidget,\
                               IntegerWidget,SelectionWidget,BooleanWidget,\
                               ReferenceWidget


from Products.ATCTSmallSample.config import *
from Products.Archetypes.public import IntDisplayList

SmallContentSchema = ATCTFolder.schema.copy() + Schema((

    ReferenceField('rel_val',
                   relationship='any_rel',
                   allowed_types=(),
                   multivalued=0,
                   required=True,
                   widget=ReferenceWidget(label='関連づけ',
                                          description='Plone内のオブジェクトにリンクします')
                 ),

    BooleanField('bool_val',
                 default=False,
                 required=True,
                 widget=BooleanWidget(label='真偽値',
                                      description='真偽値を保持します',
                                      ),
                 ),

    IntegerField('stock',
                 default=0,
                 required=True,
                 widget=IntegerWidget(label='Int値(自由入力)',
                                      description='任意の数値を自由に入力します',
                                      ),
                 ),

    IntegerField('int_val',
                 default=0,
                 vocabulary=IntDisplayList([(i, i) for i in range(0, 101)]),
                 widget=SelectionWidget(label='Int値(選択)',
                                        description='0～100までの数値を選択します',
                                        format='select',
                                        ),
                 ),

    ))




#Finalize schema definition
finalizeATCTSchema(SmallContentSchema)


class SmallContent(ATCTFolder):
    """
        create SmallContent instance.

    >>> from Products.ATCTSmallSample.content.smallcontent import SmallContent
    >>> small = SmallContent('small')
    >>> small.meta_type
    'SmallContent'

        test IInlineObject interface existing.

    >>> from Products.COREBlog2.interfaces.IInlineObject import IInlineObject
    >>> bool(IInlineObject.isImplementedBy(small))
    True

    """

    schema         = SmallContentSchema

    content_icon   = 'smallcontent.gif'
    meta_type      = 'SmallContent'
    portal_type    = 'SmallContent'
    archetype_name = 'SmallContent'
    immediate_view = 'base_view'
    default_view   = 'base_view'
    suppl_views    = ()
    typeDescription= 'A small content.'
    typeDescMsgId  = 'small_content_description'
    assocMimetypes = ()
    assocFileExt   = ()
    cmf_edit_kws   = ()
    global_allow   = True
    filter_content_types = False
    allowed_content_types = ()
    _at_rename_after_creation = True

    __implements__ = (ATCTFolder.__implements__, INonStructuralFolder, )

    # implement for coreblog IInlineObject interface
    try:
        from Products.COREBlog2.interfaces.IInlineObject import IInlineObject
        __implements__ += (IInlineObject,)
    except:
        pass


    security = ClassSecurityInfo()

    def canSetDefaultPage(self):
        """Can this content set default page for folder?"""
        return False

    def isInlineObject(self):
        """Is this content inline object or not?

        >>> small.isInlineObject()
        True

        """
        return True

    def getInlineView(self):
        """For IInlineObject's inline view, if isInlineObject return True.

        >>> small.getInlineView()
        ('smallcontent_inline_view', 'inline_view')

        """

        templ = 'smallcontent_inline_view'
        macro = 'inline_view'
        return templ, macro

    def getAttachmentView(self):
        """For IInlineObject's attachement view, if isInlineObject return False.

        >>> small.getAttachmentView() is None
        True

        """
        pass


registerType(SmallContent, PROJECTNAME)

